.razzi-category-links{
	text-align: center;

	ul{
		list-style: none;
		white-space: nowrap;
		padding: 0;
		margin: 0;
		overflow-x: auto;
		overflow-y: hidden;
		display: flex;
	    flex-wrap: nowrap;
		// justify-content: center;

		li{
			display: inline-block;
			padding: 13px 50px;
			position: relative;


			a{
				font-weight: 500;
			}

			&:first-child{
				padding-left: 0;
			}

			&:last-child{
				padding-right: 0;
			}

			&:not(:last-child){

				&:after{
					content: '';
					display: block;
					position: absolute;
					right: 0;
					top: 50%;
					transform: translateY(-50%);
					width: 1px;
					height: 12px;
					background-color: #cdcdcd;
				}

			}

		}

		&::-webkit-scrollbar{
			display: none;
		}
	}
}