.razzi-topbar__text{
    color: var(--rz-color-dark);
    letter-spacing: 0.02em;
    text-transform: uppercase;
    font-size: 11px;
    font-weight: 500;
    display: flex;

    svg,
	img{
        margin: 0 14px 0 0;
        vertical-align: middle;
    }

    .razzi-svg-icon{
        svg{
            width: auto;
            height: auto;
        }
    }

    &.text-normal {
        text-transform: inherit;
    }
}

.topbar-menu{
    padding: 0;
    margin: 0;
    list-style: none;
    margin-left: -12px;
    margin-right: -12px;
    display: flex;

    ul.sub-menu {
        min-width: 80px;
        position: absolute;
        top: 100%;
        left: 0;
        opacity: 0;
        transition: .3s;
        z-index: 1000;
        pointer-events: none;
        text-align: left;
        background-color: var(--rz-background-color-light);
        box-shadow: 0px 2px 6px rgba(0, 0, 0, 0.05);
        list-style: none;
        margin: 0;
        padding: 0;

        li:not(:last-child) {
            border-bottom: 1px solid var(--rz-border-color-light);
        }

        ul {
            left: 100%;
            top: 0;
            transform: scaleX(1);
        }
    }

    li{
        display: inline-block;
        width: 100%;
        position: relative;

        a{
            display: block;
            width: 110%;
            font-size: 14px;
            padding: 10px 14px 9px;
            margin: 0;
            opacity: 1;
            white-space: nowrap;
            color: #111;

            &:hover{
                color: var(--rz-color-primary);
            }
        }

        &:hover {
            > ul {
                opacity: 1;
                transform: scaleX(1);
                pointer-events: initial;
            }
        }
    }

    > li {
        display: flex;
        align-items: center;
        height: inherit;

        > a {
            font-weight: 500;
            color: var( --rz-color-dark );
        }

        &.menu-item-has-children > a {
            position: relative;
            padding-right: 20px;

            .toggle-menu-children {
                right: 0;
                -webkit-transform: translateY(-50%) rotate(0);
                -moz-transform: translateY(-50%) rotate(0);
                -o-transform: translateY(-50%) rotate(0);
                -ms-transform: translateY(-50%) rotate(0);
                transform: translateY(-50%) rotate(0);
            }
        }
    }

    .menu-item-has-children {
        position: relative;
        padding-right: 20px;

        .toggle-menu-children {
            position: absolute;
            right: 9px;
            top: 50%;
            transform: translateY(-50%);
            line-height: 1;
            cursor: pointer;
            transition: .3s transform;
            -webkit-transform: rotate(-90deg);
            -moz-transform: rotate(-90deg);
            -o-transform: rotate(-90deg);
            -ms-transform: rotate(-90deg);
            transform: rotate(-90deg);
        }
    }
}

.topbar-menu-container {
    .topbar-menu {
        ul {
            a {
                padding: 0;

                &:hover {
                    --rz-color-primary: #FF6F61;
                }
            }
        }

        li {
            &.row-flex {
                display: flex;
            }

            li {
                a {
                    --rz-color-dark: #111111;
                }
            }
        }

        > li {
            > a {
                padding: 0 2px;
                position: relative;

                &:after {
                    display: none;
                }
            }

            &.menu-item-has-children > a {
                padding-right: 3px;
            }
        }
    }

    ul.sub-menu li:not(:last-child) {
        border: none;
    }

    &.has-arrow {
        .topbar-menu {
            > li {
                &.menu-item-has-children > a {
                    padding-right: 20px;
                }
            }
        }
    }
}

.topbar{
	--rz-icon-color: #A0A0A0;

    .razzi-currency,
    .razzi-language {
        padding: 0 20px;
        width: fit-content;

        &:not(:last-child):before {
            content: '';
            display: block;
            position: absolute;
            right: 0;
            top: 50%;
            transform: translateY(-50%);
            width: 1px;
            height: 10px;
            background-color: #cdcdcd;
        }

        .content-droplist ul li a {
            color: #111;
        }
    }

    .socials-menu{
        .menu{
            margin-left: -10px;
            margin-right: -10px;

            li{
                padding: 0;

                a{
                    display: inline-block;
                    color: var(--rz-icon-color);
                    padding: 0 10px;
                    font-size: 14px;

                    &:hover {
                        color: var(--rz-dark-color);
                    }
                }
            }
        }
    }

    .primary-navigation {
        ul {
            ul {
                a {
                    color: #111;
                }
            }
        }

        .nav-menu {
            > li {
                > a {
                    font-size: 16px;
                }
            }
        }
    }

    .razzi-topbar__close{
        cursor: pointer;
    }
}