.footer-payments{

    .payments{
        list-style: none;
        padding: 0;
        margin: 0 -2.5px;
    }

    li{
        display: inline-block;
        padding: 0 2.5px;

        a{
           display: block;
        }
    }
}

.footer-branding{
    .logo.logo-text{
        font-size: 40px;
        font-weight: 600;
    }
}