.razzi-banner-collection{
    position: relative;

    &:hover {
        .razzi-banner-clt__content-inner {
            box-shadow: 0px 10px 20px rgba(0, 0, 0, 0.02);
        }
    }
}

.razzi-banner-clt__content {
    position: absolute;
    bottom: 50%;
    transform: translateY(50%);
    left: 0;
    right: 0;
    display: flex;
    justify-content: center;
    z-index: 1;
}

.razzi-banner-clt__content-title{
    font-size: 28px;
    margin: 0 0 12px;
}

.razzi-banner-clt__content-desc{
    font-size: 15px;
    color: var(--rz-color-dark);
    padding-bottom: 8px;
}

.razzi-banner-clt__content-inner {
    padding: 32px 71px 0;
    background-color: #fff;
    text-align: center;
    max-width: 425px;
    transition: 0.35s;
}

.razzi-banner-clt__content-button{
    transform: translateY(25px);
    padding: 0 34px;
}

.razzi-banner-clt__images{
    display: flex;
    flex-wrap: wrap;
    img{
        display: block;
    }
}

.razzi-banner-clt__images-item {
    position: relative;

    &:before {
        content: '';
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: transparent;
        z-index: 1;
    }
}

.razzi-banner-clt-link {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    z-index: 2;
}