.razzi-advanced-tabs {
	padding: 0 100px;

	&.razzi-swiper-carousel-elementor {
		.swiper-container {
			position: static;
		}

		.rz-swiper-button {
			font-size: 24px;
			width: auto;
			height: auto;
			line-height: 1;
			color: #CDCDCD;

			&:hover {
				color: #A0A0A0;
			}
		}

		.rz-swiper-button-prev {
			left: -105px;
		}

		.rz-swiper-button-next {
			right: -105px;
		}

		.swiper-button-lock {
			+ .swiper-wrapper {
				justify-content: center;
			}
		}
	}
}

.razzi-advanced-tabs__nav {
	display: flex;
	justify-content: center;
	list-style: none;
	margin: 0 -10px 75px;
	padding: 0;

	li {
		padding-left: 10px;
		padding-right: 10px;
	}
}

.razzi-advanced-tabs__title {
	position: relative;
	font-size: 16px;
	font-weight: 500;
	line-height: 1;
	color: var(--rz-color-dark);
	padding: 0 5px;

	&::after {
		content: "";
		position: absolute;
		right: 0;
		bottom: -3px;
		width: 0;
		border-bottom: 1px solid transparent;
		transition: .4s;
	}

	&:hover,
	&.active {
		color: var(--rz-color-primary);

		&::after {
			width: 100%;
			left: 0;
			right: auto;
			border-color: var(--rz-color-primary);
		}
	}
}

.razzi-advanced-tabs__content {
	position: relative;
}

.razzi-advanced-tabs__panel {
	position: absolute;
    top: 0;
    left: 0;
	width: 100%;
    z-index: -1;
    opacity: 0;
    transition: opacity 0.4s ease;
    transform: translateY(10px);

	&.active {
		position: relative;
		z-index: 2;
		opacity: 1;
		top: 0;
		transform: translateY(0);
		transition: all 0.4s ease;
		transition-delay: 0.1s;
	}
}

.razzi-advanced-tabs__item {
	display: inline-flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
	margin-top: 6px;
	margin-right: 30px;
	padding: 15px;
	width: 170px;
	min-height: 170px;
	border: 1px solid #E2E2E2;

	&:hover {
		transform: translateY(-6px);
		box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.15);
	}

	&:last-child {
		margin-right: 0 !important;
	}
}

.razzi-advanced-tabs__icon {
	font-size: 51px;
	color: var(--rz-color-primary);
	margin-bottom: 14px;
}

.razzi-advanced-tabs__content-title {
	font-size: 20px;
	font-weight: 500;
	color: var(--rz-color-dark);
}