.razzi-testimonials-grid{
    .heading-title{
        font-size: 36px;
        line-height: (48/36);
        margin: 0 0 76px;
        text-align: center;
    }

    .testimonials-wrapper{
        margin: 0 -15px;
    }

    .testimonial-item{
        padding: 0 15px 30px;
    }

    .testimonial-item__inner{
        margin-top: 50px;
        padding: 84px 37px 34px;
        position: relative;
        background-color: #f5f5f5;
        text-align: center;

        .testi-image{
            position: absolute;
            top: -50px;
            left: 0;
            right: 0;
            max-width: 100px;
            margin: auto;
        }

        .testi-desc{
            font-size: 18px;
            color: #111111;
            margin-bottom: 27px;
        }

        .testi-rate{
            margin-bottom: 2px;
        }

        .testi-meta{
            font-size: 14px;
        }
    }

    .razzi-svg-icon{
        font-size: 14px;
        color: #cdcdcd;

        &.rate-active{
            color: #F8B86D;
        }
    }

    .testi-button{
        display: flex;
        justify-content: center;
        padding-top: 46px;
        text-decoration: none;
        clear: both;
    }
}
