.rz-modal {
	position: fixed;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 1600;
	display: none;
	--rz-modal-spacing: 30px;

	.panel-content {
		position: absolute;
		right: 0;
		top: 0;
		height: 100%;
		width: 470px;
		max-width: 100%;
		margin: 0;
		background-color: var(--rz-background-color-light);
		transform: translateX(100%);
		transition: transform .5s;
		display: flex;
		flex-direction: column;
	}

	.modal-header {
		padding: 25px 45px 20px 20px;
		display: flex;
		align-items: center;
		justify-content: center;
		position: relative;
		background-color: var(--rz-background-color-light);
		border-bottom: 1px solid #e5e5e5;
		text-align: center;

		.modal-title {
			font-size: 18px;
			font-weight: 500;
			margin: 0;
			line-height: 1;
		}
	}

	.mobile-panel-search {
		width: 100%;
		padding: var(--rz-modal-spacing);

		.search-wrapper {
			position: relative;
			width: 100%;
			display: flex;
		}

		.search-field {
			flex: auto;
			border: 1px solid var(--rz-border-color-gray);
			padding-right: 42px;
			height: 54px;
			line-height: 54px;
		}

		.search-submit {
			position: absolute;
			right: 0;
			background-color: transparent;
			color: var(--rz-text-color-gray);
			padding: 0;
			width: 68px;
			height: 54px;
			line-height: 56px;
			display: block;
			text-align: center;
			z-index: 999;
			border: none;
			transition: none;
		}
	}

	.modal-content {
		position: relative;
		padding: var(--rz-modal-spacing);
		background-color: var(--rz-background-color-light);
	}

	&.open {
		visibility: visible;

		.modal-header {
			opacity: 1;
			display: block;
		}

		.modal-content {
			opacity: 1;
		}

		.panel-content {
			transform: none;
		}
	}

	&.side-left {
		.panel-content {
			left: 0;
			right: auto;
			transform: translateX(-100%);
		}

		&.open {
			.panel-content {
				transform: none;
			}
		}
	}

	.off-modal-layer {
		position: absolute;
		top: 0;
		left: 0;
		width: 100%;
		height: 100%;
		cursor: pointer;
		background-color: var(--rz-background-color-dark);
		opacity: 0.5;
	}

	.button-close {
		display: flex;
		line-height: 1;
		position: absolute;
		right: var(--rz-modal-spacing);
		top: 50%;
		transform: translateY(-50%);
		font-size: 24px;
		color: #a6a6a6;
		margin-left: 20px;

		&:hover {
			color: #767676;
		}
	}
}

.admin-bar {
	.rz-modal {
		top: 32px;
		height: calc( 100% - 32px );
	}
}

body .hotspot-modal {
	color: var(--rz-text-color);
    font-family: var(--rz-font-family-primary);

	.public-hotspot-info-holder .public-hotspot-info {
		.public-hotspot-info__number {
			display: none;
		}

		.public-hotspot-info__btn-buy.snpt-cta-btn {
			font-size: 10px;
			letter-spacing: 0;
			font-weight: 400;
			padding: 5px 7px 4px;
			background-color: #111 !important;
			color: #fff !important;
			line-height: 1;

			&:hover {
				background-color: #111;
				color: #fff;
			}
		}

		.public-hotspot-info__price {
			color: var(--rz-text-color-gray);
			font-size: 16px;
			font-weight: 500;
			padding-top: 3px;
			display: inline-block;
		}

		.public-hotspot-info__second-line {
			font-size: 16px;
			margin-top: 5px;
		}
	}

	.modal-dialog .chevron {
		top: 50%;
		transform: translateY(-50%);
	}

}