.wp-block-button{
	margin-bottom: 25px;

	.wp-block-button__link {
		cursor: pointer;
		display: inline-block;
		margin: 0;
		padding: 12px 25px;
		line-height: 1.5;
		font-size: 16px;
		font-weight: 500;
		text-align: center;
		text-decoration: none;
		overflow-wrap: break-word;
		color: #fff;

		&:hover{
			text-decoration: none !important;
		}
	}

	&.is-style-outline .wp-block-button__link{
		border: 1px solid;
		color: var(--rz-color-dark);

		&:not(.has-background),
		&:focus:not(.has-background),
		&:active:not(.has-background){
			background: transparent;
		}
	}

	&.is-style-squared{
		.wp-block-button__link{
			border-radius: 0;
		}
	}

	&:not(.is-style-outline){
		color: #fff;
	}
}