.ra-account-modal {
	.modal-content {
		height: 100%;
		flex-direction: column;
		justify-content: center;
		padding-left: 50px;
		padding-right: 50px;

		.form-row {
			padding: 0;
		}

		form {
			display: flex;
			flex-direction: column;
			justify-content: center;
			height: 100%;
		}


	}

	.woocommerce-error {
		.error-message {
			margin: 0;
			padding: 0;
			list-style-type: none;
		}

	}

	.razzi-button {
		width: 100%;
		line-height: 50px;
		cursor: pointer;

		&.razzi-loading:before {
			left: 50%;
			top: -10px;
		}

		&.button-medium {
			line-height: 48px;
		}

		&.create-account {
			margin-top: 20px;
		}
	}

	form.register {
		button.razzi-button {
			margin: 20px 0 0 0;
		}
	}


	div.nsl-container.nsl-container-block .nsl-container-buttons {
		width: 100%;
	}

}