.razzi-products-listing{
	ul.swiper-wrapper {
        margin: 0;
        box-sizing: border-box;

        li {
            clear: none;
            padding-left: 0;
            padding-right: 0;
            margin-bottom: 0;
        }
    }

	ul.products {
        flex-wrap: nowrap;
        list-style: none;

        &:not(.swiper-wrapper) {
			overflow: hidden;
		}

        li.product {
            padding-left: 0;
            padding-right: 0;
            margin-bottom: 0;

            &:not(.swiper-slide) {
                flex-shrink: 0;
                margin-right: 30px;
            }

            .price {
                color: var(--rz-color-dark);
            }
        }
    }

	.swiper-container-multirow{
		ul.products {
			flex-wrap: wrap;
		}
	}

	.razzi-products-listing__image{
		margin-right: 30px ;
		max-width: 90px;
	}

    .razzi-products-listing__item-box{
        display: flex;
        margin: 1px;
        box-shadow: 0px 0px 1px rgba(0, 0, 0, 0.4);
        padding: 19px 20px 19px 20px;
    }
}

.razzi-products-listing__heading {
    font-size: 28px;
    font-weight: 500;
}

.razzi-products-listing__items{
	display: flex;
}

.razzi-products-listing__content{
	margin-top: 4px;
	color: var(--rz-color-dark);
}

.razzi-products-listing__title{
	font-size: 16px;
}

.razzi-products-listing__price{
	margin-top: 10px;
	font-size: 16px;
	font-weight: 500;
}

.razzi-products-listing__heading--arrows {
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-bottom: 47px;

    .razzi-products-listing__arrows {
        margin-right: 97px;
    }

    .rz-swiper-button {
        position: static;
        transform: none;
        width: auto;
        height: auto;
        line-height: normal;
        font-size: 16px;
        width: 30px;
        height: 30px;
        line-height: 30px;
        color: #111;
        background-color: #f5f5f5;
    }
}