/*--------------------------------------------------------------
## Menus
--------------------------------------------------------------*/
@import "navigation/menu-socials";
@import "navigation/breadcrumb";
@import "navigation/nav-ajax";

.comment-navigation,
.posts-navigation,
.post-navigation {
	margin: 0 0 1.5em;
	overflow: hidden;

	.nav-previous {
		float: left;
		width: 50%;
	}

	.nav-next {
		float: right;
		text-align: right;
		width: 50%;
	}
}

.razzi-menu-badges {
	--rz-badges-bg-color: #dd3333;
	white-space: nowrap;
    font-weight: 600;
    font-size: 9px;
	line-height: 12px;
	padding: 2px 4px;
	bottom: 15px;
    right: -5px;
	background-color: var(--rz-badges-bg-color);
	color: var(--rz-color-lighter);
	position: relative;

	&:before {
		content: "";
		position: absolute;
		top: 100%;
		left: 0;
		border: 4px solid;
		border-right-color: transparent !important;
		border-bottom-color: transparent !important;
		border-right-width: 7px;
		border-left-width: 0;
		border-color: var(--rz-badges-bg-color);
	}
}