@import "site/header/account/account-modal";

.site-header .header-account {
	height: inherit;

	.account-icon {
		font-size: 17px;
		display: flex;
		align-items: center;
		height: inherit;
		position: relative;
		top: -2px;
		color: var(--rz-header-color-dark);
	}

	.account-links {
		display: none;
	}
}

.ra-account-modal .modal-content {
	padding-left: 20px;
	padding-right: 20px;
}

.ra-hamburger-modal ul.nav-menu > li .razzi-svg-icon {
	font-size: 14px;
}

.ra-account-modal .modal-content form {
	height: auto;
	margin-top: 40px;
}