.single-product {
	div.product {
		.quantity {
			margin-right: 20px;
			.qty {
				width: 83px;
				font-size: 18px;
				padding-left: 20px;
				padding-right: 20px;
				color: var(--rz-text-color);
				height: 54px;
				line-height: 54px;
			}
			.qty-dropdown {
				.current {
					width: 83px;
					height: 54px;
					line-height: 54px;
					font-size: 18px;
					padding: 0 20px;

					&.focus {
						border-color: var(--rz-border-color-darker);
						z-index: 1001;
					}
				}

				.razzi-svg-icon {
					font-size: 11px;
					margin-top: 0;
					transform: translateY(-50%);
					right: 20px;
				}

				.qty-options {
					top: calc(100% - 1px);
					width: 100%;
					height: 180px !important;

					ul li {
						padding: 4.5px 20px;
						font-size: 18px;
					}
				}
			}
		}
	}
}