// Flex

.row-flex {
    display: flex;
    flex-wrap: wrap;
    margin-left: -15px;
    margin-right: -15px;
}

.col-flex {
    min-height: 1px;
    padding-left: 15px;
    padding-right: 15px;
}

// Define flex columns
$i: 12;
@while $i > 0 {
    .col-flex-xs-#{$i} {
        flex: 0 0 $i / 12 * 100%;
        max-width: $i / 12 * 100% ;
    }

    $i: $i - 1;
}

// 5 Columns
.col-flex-xs-1-5 {
    flex: 0 0 20%;
    max-width: 20%;
}

@media (min-width: 768px) {
    $i: 12;
    @while $i > 0 {
        .col-flex-sm-#{$i} {
            flex: 0 0 $i / 12 * 100%;
            max-width: $i / 12 * 100% ;
        }

        $i: $i - 1;
    }

    // 5 Columns
    .col-flex-sm-1-5 {
        flex: 0 0 20%;
        max-width: 20%;
    }
}

@media (min-width: 992px) {
    $i: 12;
    @while $i > 0 {
        .col-flex-md-#{$i} {
            flex: 0 0 $i / 12 * 100%;
            max-width: $i / 12 * 100% ;
        }

        $i: $i - 1;
    }

     // 5 Columns
     .col-flex-md-1-5 {
        flex: 0 0 20%;
        max-width: 20%;
    }
}
