// Extra
.footer-extra {
    --rz-footer-extra-border-color: #2b2b2b;
    --rz-footer-extra-top-spacing: 112px;
    --rz-footer-extra-bottom-spacing: 105px;

    .site-footer-dark &,
    .site-footer-custom & {
        padding-top: var( --rz-footer-extra-top-spacing );
        padding-bottom: var( --rz-footer-extra-bottom-spacing );
    }

    .site-footer-light &,
    .site-footer-gray &{
        .footer-container {
            padding-top: var( --rz-footer-extra-top-spacing );
            padding-bottom: var( --rz-footer-extra-bottom-spacing );
        }
    }

    &.has-divider{
        .footer-container {
            &:before {
                content: '';
                position: absolute;
                top: 0;
                left: 0;
                right: 0;
                width: 100%;
                height: 1px;
                background-color: var( --rz-footer-extra-border-color );
            }
        }
    }
}

.footer-extra__inner{
    text-align: center;

    > *:not(:last-child){
        margin-bottom: 32px;
    }
}
