/*
Theme Name: Razzi
Description: Used to style Gutenberg Blocks in the editor.
*/

.editor-styles-wrapper.edit-post-visual-editor p.wp-block-subhead {
    font-size: 1.1em;
    font-style: italic;
    opacity: .75;
    color: #666;
}

.wp-block-freeform.block-library-rich-text__tinymce ul li {
    margin-bottom: 0;
}

.wp-block-freeform.block-library-rich-text__tinymce ol,
.wp-block-freeform.block-library-rich-text__tinymce ul {
    margin: 0 0 1.5em;
    padding-left: 1.5em;
}

.wp-block-freeform.block-library-rich-text__tinymce ol ol,
.wp-block-freeform.block-library-rich-text__tinymce ul ul,
.wp-block-freeform.block-library-rich-text__tinymce ul ol,
.wp-block-freeform.block-library-rich-text__tinymce ol ul {
    margin-bottom: 0;
}

.block-library-list .editor-rich-text__tinymce,
.block-library-list .editor-rich-text__tinymce ol,
.block-library-list .editor-rich-text__tinymce ul {
    margin-left: 0;
    padding-left: 1.5em;
}

.block-editor ul.wp-block-archives {
    padding-left: 1.5em;
}

.wp-block-freeform.block-library-rich-text__tinymce pre {
    background: #eee;
    font-family: "Courier 10 Pitch", Courier, monospace;
    font-size: 13px;
    line-height: 1.6;
    margin-bottom: 1.6em;
    max-width: 100%;
    overflow: auto;
    padding: 1.6em;
}

.editor-post-title__block .editor-post-title__input {
    font-family: "Jost", sans-serif;
    font-weight: 500;
    font-size: 48px;
    color: #111;
    text-align: center;
}

.post-type-post .editor-styles-wrapper{
    font-size: 18px;
}

.wp-block-cover-image.has-background-dim::before,
.wp-block-cover.has-background-dim::before {
    background-color: rgba(0, 0, 0, 0.5);
    opacity: 1;
}

body .editor-styles-wrapper b, body .editor-styles-wrapper strong {
    font-weight: 500;
}

.editor-styles-wrapper .block-editor-block-list__layout.is-root-container>.wp-block[data-align=full] {
    max-width: 1000%;
}

.wp-block-freeform.block-library-rich-text__tinymce .gallery .gallery-caption {
    font-size: 16px;
    margin: 15px 0 0;
    line-height: 1.5;
}

.wp-block-freeform.block-library-rich-text__tinymce .gallery .gallery-item{
    margin-bottom: 35px;
}

.wp-block {
    max-width: 1170px;
}

.wp-block-cover {
    margin-bottom: 32px;
}

.wp-block[data-align=center]{
    clear: both;
    text-align: center;
}

body .editor-styles-wrapper .wp-block-gallery {
    margin-bottom: 40px;
    margin-left: auto;
    margin-right: auto;
}


[data-align=left] .wp-block-cover,
[data-align=left] .wp-block-cover-image,
[data-align=right] .wp-block-cover,
[data-align=right] .wp-block-cover-image{
    max-width: 420px;
    width: 100%;
}


body .is-sidebar-opened .editor-styles-wrapper *.alignwide{
    width: -webkit-fill-available;
}

body .editor-styles-wrapper .wp-block-button__link {
    cursor: pointer;
    display: inline-block;
    margin: 0;
    padding: 12px 25px;
    line-height: 1.5;
    font-size: 16px;
    font-weight: 500;
    text-align: center;
    text-decoration: none;
    overflow-wrap: break-word;
    border-radius: 9999px;
}

body .wp-block-button {
    display: block;
}


body .wp-block-quote.is-large cite, body .wp-block-quote.is-large footer, body .wp-block-quote.is-style-large cite, body .wp-block-quote.is-style-large footer {
    text-align: left;
}

body .editor-styles-wrapper a {
    text-decoration: none;
}

body .editor-styles-wrapper .wp-block-archives-dropdown select:disabled {
    background-image: url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTAiIGhlaWdodD0iNSIgdmlld0JveD0iMCAwIDEwIDUiIGZpbGw9Im5vbmUiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+DQo8cGF0aCBkPSJNNC41MDQ5NSA0LjgyMDExTDAuMjA1MjQxIDEuMDQ4NTZDLTAuMDY4NDEzNyAwLjgwODY0NiAtMC4wNjg0MTM3IDAuNDE5NjYzIDAuMjA1MjQxIDAuMTc5ODY0QzAuNDc4NjUyIC0wLjA1OTk1NDcgMC45MjIwOTggLTAuMDU5OTU0NyAxLjE5NTQ5IDAuMTc5ODY0TDUuMDAwMDcgMy41MTcxTDguODA0NTIgMC4xNzk5NjFDOS4wNzgwNSAtMC4wNTk4NTc3IDkuNTIxNDUgLTAuMDU5ODU3NyA5Ljc5NDg2IDAuMTc5OTYxQzEwLjA2ODQgMC40MTk3OCAxMC4wNjg0IDAuODA4NzQzIDkuNzk0ODYgMS4wNDg2Nkw1LjQ5NTA4IDQuODIwMkM1LjM1ODMxIDQuOTQwMTEgNS4xNzkyNSA1IDUuMDAwMDkgNUM0LjgyMDg1IDUgNC42NDE2NSA0Ljk0IDQuNTA0OTUgNC44MjAxMVoiIGZpbGw9IiM3Njc2NzYiLz4NCjwvc3ZnPg0K);
    background-repeat: no-repeat;
    background-size: auto;
    background-position: calc(100% - 20px) 50%;
    -webkit-appearance: none;
}

body .editor-styles-wrapper .alignleft {
    margin-right: 1.5em;
}

body .editor-styles-wrapper .alignright {
    margin-left: 1.5em;
}

table.wp-calendar-table td a {
    text-decoration: underline;
}

.editor-styles-wrapper .wp-block[data-align=full] > .wp-block-columns p:not(.has-background), .editor-styles-wrapper .wp-block[data-align=full] > .wp-block-columns h1:not(.has-background), .editor-styles-wrapper .wp-block[data-align=full] > .wp-block-columns h2:not(.has-background), .editor-styles-wrapper .wp-block[data-align=full] > .wp-block-columns h3:not(.has-background), .editor-styles-wrapper .wp-block[data-align=full] > .wp-block-columns h4:not(.has-background), .editor-styles-wrapper .wp-block[data-align=full] > .wp-block-columns h5:not(.has-background), .editor-styles-wrapper .wp-block[data-align=full] > .wp-block-columns h6:not(.has-background) {
    padding-left: 15px;
    padding-right:  15px;
}

.wp-block-search .wp-block-search__label {
    font-size: 16px;
    font-weight: 600;
    margin: 0 0 5px;
    display: block;
    color: var(--rz-color-dark);
}

.wp-block-search .wp-block-search__input {
    border: 1px solid var(--rz-border-color);
    padding: 12px 15px;
    font-size: 16px;
}

.wp-block-search .wp-block-search__button.wp-block-search__button.wp-block-search__button {
    line-height: 52px;
    height: 52px;
    padding: 0 15px;
    white-space: normal !important;
    min-width: auto !important;
}

.editor-styles-wrapper .wp-block-group > h2 {
    font-size: 16px;
    font-weight: 600;
    text-transform: uppercase;
    line-height: 1;
    margin: 0 0 20px;
    padding: 0 0 13px;
    border-bottom: 2px solid;
    display: block;
}

.editor-styles-wrapper .wp-block-code code {
    background: transparent;
}

.wp-block-widget-area__inner-blocks > .block-editor-block-list__layout > .wp-block:not(.wp-block-pullquote, .wp-block-list, .block-list-appender, .wp-block-code, .wp-block-preformatted, .wp-block-quote, .wp-block-legacy-widget, .wp-block-calendar) {
    margin: 0 0 40px;
    padding: 23px;
    border: 1px solid #e2e2e2;
}

.wp-block-calendar .wp-block-calendar {
    background-color: #fafafa;
	border: 1px solid #ccc;
	padding: 21px 19px 12px;
}

.wp-block-calendar .wp-calendar-table {
    margin-bottom: 5px;
    border: none;
}

.wp-block-calendar .wp-calendar-table caption {
	margin-bottom: 15px;
	font-weight: 600;
    text-align: center;
}

.wp-block-calendar thead, .wp-block-calendar tbody {
	border: none;
	margin-left: -.25em;
	margin-right: -.25em;
}

.wp-block-calendar thead th, .wp-block-calendar thead td, .wp-block-calendar tbody th, .wp-block-calendar tbody td {
	background: transparent;
	border: 0;
	text-align: center;
	line-height: 2;
	vertical-align: middle;
	word-break: normal;
}

.wp-block-calendar thead th {
	visibility: hidden;
	position: relative;
	font-size: 14px;
	color: #999;
}

.wp-block-calendar thead th:after {
	content: '';
	visibility: visible;
	display: block;
	position: absolute;
	top: 0;
	left: 50%;
	transform: translateX(-50%);
}

.wp-block-calendar thead th[title="Monday"]:after {
	content: 'Mo';
}

.wp-block-calendar thead th[title="Tuesday"]:after {
	content: 'Tu';
}

.wp-block-calendar thead th[title="Wednesday"]:after {
	content: 'We';
}

.wp-block-calendar thead th[title="Thursday"]:after {
	content: 'Th';
}

.wp-block-calendar thead th[title="Friday"]:after {
	content: 'Fr';
}

.wp-block-calendar thead th[title="Saturday"]:after {
	content: 'Sa';
}

.wp-block-calendar thead th[title="Sunday"]:after {
	content: 'Su';
}

.wp-block-calendar tbody td {
	font-size: 14px;
	color: #000;
}

.wp-block-calendar tbody #today {
	position: relative;
	z-index: 9;
	color: #fff;
}

.wp-block-calendar tbody #today:after {
	content: '';
	position: absolute;
	top: 50%;
	left: 50%;
	transform: translate(-50%, -50%);
	width: 28px;
	height: 28px;
	background-color: #FF6F61;
	border-radius: 50%;
	z-index: -1;
}

.wp-block-calendar tbody .old {
	color: #999;
}

.wp-block-calendar .wp-calendar-nav a {
	color: #000;
	text-decoration: none;
}

.wp-block-calendar .wp-calendar-nav a:hover {
	color: #FF6F61;
}

.editor-styles-wrapper .wp-block-page-list {
	margin: 0;
	padding: 0;
}

.wp-block-page-list li {
    list-style: none;
    padding: 7px 0;
}

.wp-block-page-list li:last-child {
    padding-bottom: 0;
}

.wp-block {
    max-width: 780px;
}

.editor-styles-wrapper .wp-block[data-align=wide], .editor-styles-wrapper .wp-block.alignwide {
    max-width: 1170px;
}

.editor-styles-wrapper .block-editor-block-list__layout.is-root-container>.wp-block[data-align=full] {
    margin-left: -8px;
    margin-right: -8px;
}

.editor-styles-wrapper .wp-block[data-align=full], .editor-styles-wrapper .wp-block.alignfull {
    max-width: none;
}

.post-type-page .editor-post-title__block .editor-post-title__input {
    font-size: 32px;
}

.post-type-page .wp-block {
    max-width: 1170px;
}


.post-type-page .editor-styles-wrapper .wp-block[data-align=wide], .post-type-page .editor-styles-wrapper .wp-block.alignwide {
    max-width: 1380px;
}

.wp-block-widget-area__inner-blocks .wc-block-grid__product-rating .star-rating {
	display: inline-block;
    width: auto;
	line-height: 1;
}

.wp-block-widget-area__inner-blocks .wc-block-grid__product-rating .star-rating::before,
.wp-block-widget-area__inner-blocks .wc-block-grid__product-rating .star-rating span::before {
	display: none;
}

.wp-block-widget-area__inner-blocks .wc-block-grid__product-rating .rating-stars {
	display: block;
	line-height: 1;
	padding-top: 0;
}

.wp-block-widget-area__inner-blocks .wc-block-grid__product-rating .rating-stars span {
	padding-top: 0;
	position: static;
}

.wp-block-widget-area__inner-blocks .wc-block-grid__product-rating .max-rating {
	position: static;
	overflow: visible;
}

.wp-block-widget-area__inner-blocks .wc-block-grid__product-rating .max-rating .razzi-svg-icon {
    color: #CDCDCD;
}

.wp-block-widget-area__inner-blocks .wp-block-button .wp-block-button__link {
	border-radius: 0;
    color: #fff;
}

.wp-block-widget-area__inner-blocks .wc-block-components-sort-select {
	margin-bottom: 30px;
}

.wp-block-widget-area__inner-blocks .wc-block-components-sort-select__select {
	width: auto;
}

.wp-block-widget-area__inner-blocks .wc-block-product-categories.wc-block-product-categories ul {
    margin-left: 0;
    list-style: none;
}

.wp-block-widget-area__inner-blocks .wc-block-grid__product .wc-block-grid__product-price del {
    font-size: 14px;
    color: #a6a6a6;
    font-weight: 500;
}

.wp-block-widget-area__inner-blocks .wc-block-grid__product .wc-block-grid__product-price ins {
    font-size: 16px;
    color: var(--rz-color-primary);
    background-color: transparent;
    padding-left: 5px;
    font-weight: 500;
}