.razzi-posts-listing{
	.entry-header{
		margin-right: 30px;
		margin-bottom: 0;
		flex: 1 0 170px;
	}

	.blog-wrapper{
		display: flex;
		align-items: center;
		margin-bottom: 20px;

		&:last-child{
			margin-bottom: 0;
		}
	}

	a.post-thumbnail{
        display: flex;
    }
}