.next-posts-navigation{
    display: block;
    text-align: center;

    .nav-previous-ajax{
        display: inline-block;
        position: relative;

        a {
            display: block;
            font-weight: 600;
            padding: 11px 45px;
            border: 1px solid var(--rz-border-color-dark);
            transition: 0.35s;

            &:hover {
                background-color: var(--rz-color-dark);
                color: var(--rz-color-lighter);
            }
        }

    }

    .razzi-gooey-loading{
        position: absolute;
        width: 100%;
        height: 100%;
        left: 0;
        top: 0;
        opacity: 0;
        z-index: -1;
        transition: cubic-bezier(0.075, 0.82, 0.165, 1);
    }

    &.loading{
        .razzi-gooey-loading{
            opacity: 1;
            z-index: 1;
        }
    }
}