@import "site/default/button";
@import "site/default/quote";
@import "site/default/image";
@import "site/default/widget";
@import "site/default/cover";
@import "site/default/columns";
@import "site/default/embeds";
@import "site/default/layout-el";

.wp-block-table td,
.wp-block-table th{
	padding: 10px 20px;
    border-color: var(--rz-border-color-gray);
}


table.large-padding thead th,
table.large-padding thead td,
table.large-padding th,
table.large-padding td {
	padding: 10px;
}

button,
[type="button"],
[type="reset"],
[type="submit"],
input[type="text"],
input[type="email"] {
	-webkit-appearance: none;
	appearance: none;
	border-radius: 0;
}