// Widget
.footer-widgets{
    color: var(--rz-text-color-gray);
    --rz-footer-widget-border-color: #2b2b2b;
    --rz-footer-widget-top-spacing: 64px;
    --rz-footer-widget-bottom-spacing: 64px;

    .site-footer-dark &,
    .site-footer-custom & {
        padding-top: var( --rz-footer-widget-top-spacing );
        padding-bottom: var( --rz-footer-widget-bottom-spacing );
    }

    .site-footer-light &,
    .site-footer-gray &{
        .footer-container {
            padding-top: var( --rz-footer-widget-top-spacing );
            padding-bottom: var( --rz-footer-widget-bottom-spacing );
        }
    }

    &.has-divider{
        .footer-container {
            &:before {
                content: '';
                position: absolute;
                top: 0;
                left: 0;
                right: 0;
                width: 100%;
                height: 1px;
                background-color: var( --rz-footer-widget-border-color );
            }
        }
    }

    .widget{
        margin-bottom: 19px;
        padding: 0;
        border: none;
    }

    .widget-title,
    .wp-block-group .wp-block-group__inner-container > h2 {
        font-size: 13px;
        line-height: (19/13);
        padding-bottom: 16px;
        margin: 0;
        border: none;
        font-weight: 500;
        letter-spacing: 0.02em;

        .razzi-svg-icon {
            display: none;
        }
    }

    .widget_text{
        line-height: 1.7;

        .widget-title{
            padding-bottom: 16px;
        }

        p{
            margin-top: 0;
        }
    }

    .widget_nav_menu{
        li{
            padding: 4px 0;

            &:first-child {
                padding-top: 0;
            }
        }
    }

    .widget_archive,
    .widget_categories {
        li {
            border: none;
        }
    }

    .razzi-widget__social-links .social-links a.social {
        color: var(--rz-text-color-gray);

        &:hover {
            color: var(--rz-text-color-hover)
        }
    }
}

.footer-widgets-area-diff{
    .diff-row{
        display: flex;
        flex-wrap: wrap;
        justify-content: space-between;
        margin-left: -15px;
        margin-right: -15px;

        > *{
            padding: 0 15px;
        }
    }
}
