/**
 * Account page
 */
 @import "shop/account";

.woocommerce-account {
    .woocommerce-ResetPassword {
        width: 100%;
    }

    .col2-set {
        margin: 0;

        .woocommerce-Address {
            width: 100%;
        }

    }

    #customer_login {
        display: block;
        .u-column1,
        .u-column2 {
            width: 100%;
            margin: 0 0 30px 0;
            padding-left: 20px;
            padding-right: 20px;
        }
    }

    .woocommerce-ResetPassword {
        .reset-depscription {
            padding: 0;
        }
    }

    .woocommerce-form-login,
    .woocommerce-form-register {
        button {
            width: 100%;
        }

        .woocommerce-LostPassword {
            text-align: left;
        }
    }
}

.woocommerce-MyAccount-navigation,
.woocommerce-MyAccount-content {
    width: 100%;
    padding: 0;
    float: none;
}

.woocommerce-MyAccount-content .greeting {
    font-size: 18px;
}

.woocommerce-MyAccount-navigation {
    overflow: hidden;
    border-bottom: 1px solid var(--rz-border-color-light);

    ul {
        display: flex;
        overflow: hidden;
        overflow-x: auto;
        margin: 0 -15px;

        li {
            padding: 0 15px 15px;
            border: none;

            &:first-child {
                border: none;
            }

            a {
                padding: 0;
                white-space: nowrap;

                .razzi-svg-icon {
                    display: none;
                }
            }
        }
    }
}

.woocommerce-MyAccount-content {
    margin-top: 50px;

    .order-item {
        padding: 15px;
    }

    > section {
        padding: 30px 15px 15px;
    }

    .form-row {
        width: 100%;
    }

    .woocommerce-columns--addresses {
        flex-direction: column;
    }

    .woocommerce-address-fields > p {
        padding: 0;
    }

    .edit-account fieldset {
        margin-top: 20px;
    }

    .edit-account fieldset legend{
        padding-top: 20px;
    }
}

table.shop_table {
    thead {
        th:first-child {
            padding-left: 15px;
        }

        tr {
            display: flex;
            flex-direction: column;

            .woocommerce-orders-table__cell {
                width: 100%;
                display: flex;
                justify-content: space-between;
                align-items: center;
                margin: 0;

                .order-title {
                    margin: 0;
                }
            }
        }
    }

    tbody {
        td.product-thumbnail {
            width: auto;
        }
    }

    .woocommerce-orders-table__cell-order-actions {
        display: flex;
        flex-direction: column;
    }
}

table.my_account_orders {
    thead {
        display: block;
    }

    > tbody {
        > tr {
            > td {
                padding: 15px;

                &:before {
                    display: none;
                }

                > table.order-image {
                    tr {
                        flex-wrap: wrap;
                    }
                }
            }
        }
    }

    .woocommerce-orders-table__cell {
        text-align: right;

        &:before {
            text-transform: uppercase;
            font-size: 12px;
            font-weight: 500;
            color: var(--rz-text-color);
        }

        &.woocommerce-orders-table__cell-order-actions {
            text-align: left;
            margin-top: 10px;
            padding: 0;

            &:before {
                display: none;
            }
        }
    }

    .order-list-image {
        padding: 20px 0 0 0;
    }
}

table.order_details {
    &.woocommerce-table--order-downloads {
        tbody {
            tr {
                td {
                    padding: 5px 0;

                    &:first-child {
                        padding-top: 20px;
                    }
                }

                &:last-child {
                    .download-file {
                        margin-bottom: 10px;
                    }
                }
            }
        }

        .download-file {
            display: flex;
            flex-direction: column;
            text-align: left;
            margin-bottom: 20px;

            a {
                margin-top: 10px;
            }
        }
    }

    .woocommerce-table__product-table {
        .product-content {
            padding-top: 0;
        }
    }
}

.woocommerce-MyAccount-content {
    .woocommerce-order-total {
        table.shop_table {
            tr {
                flex-direction: row;
                justify-content: space-between;

                > * {
                    padding: 20px 0;
                }
            }
        }
    }
}

.woocommerce-edit-address {
    .woocommerce-Addresses {
        flex-direction: column;
        margin: 0;

        > * {
            flex: 1 1 100%;
            margin: 0 0 20px 0;
        }
    }
}