<?php
/**
 * Template file for displaying mobile menu
 *
 * @package Razzi
 */
?>

<div class="mobile-menu">
	<a href="#" class="mobile-menu-toggle hamburger-menu" data-toggle="modal" data-target="mobile-menu-modal">
		<?php echo \Razzi\Icon::get_svg( 'hamburger' ); ?>
	</a>
</div>