.elementor-widget-razzi-images-carousel {
    &.hover-image-on {
        .image-item{
            &:hover {
                .content-img{
                    transform: translateY(-6px);
                }
            }
        }

        .content-img{
            padding-top: 6px;
        }

        .razzi-products-slider__icon {
            top: 21px;
        }
    }
}

.razzi-images-carousel{
    margin-left: -15px;
    margin-right: -15px;

    .content-summary{
        font-size: 1.1rem;
        text-overflow: ellipsis;
        white-space: nowrap;
        margin-top: 12px;
        color: #111;
    }

    .content-img{
        transition: transform 0.3s;

        img{
            border-radius: 50%;
            display: block;
        }
    }

    .content-subtitle{
        color: #555;
    }

    .content-text{
        background-color: var(--rz-background-color-primary);
        align-items: center;
        justify-content: center;
        width: 100px;
        height: 100px;
        max-width: 100%;
        color: #111;
        display: inline-flex;
        border-radius: 50%;
    }

    .image-item{
        text-align: center;
        padding: 0 15px;
    }

    .full-box-button{
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
    }

    .razzi-products-slider__icon {
        font-size: 18px;
        min-width: 40px;
        min-height: 40px;
        line-height: 40px;
        position: absolute;
        top: 15px;
        right: 30px;
        display: flex;
        justify-content: center;
        align-items: center;
        border-radius: 50%;
        background-color: #FF6F61;
        color: var( --rz-color-lighter );
        padding: 5px;
    }

    .swiper-scrollbar {
        max-width: 570px;
        background-color: #E2E2E2;
        cursor: pointer;
        height: 4px;
        border-radius: 0;
        position: static;
        width: 100%;
        margin: 69px auto 40px;
    }

    .swiper-scrollbar-drag {
        background-color: var(--rz-background-color-dark);
        cursor: pointer;
    }
}

.razzi-images-carousel__skew--yes {
    .razzi-images-carousel {
        transform: skewX(-10deg);

        .content-img {
            background-color: #f2f2f2;
            overflow: hidden;

            img {
                transform: skewX(10deg);
            }
        }

        .content-title {
            transform: skewX(10deg);
        }

        .swiper-scrollbar {
            margin-left: 25px;
        }
    }
}

.razzi-images-carousel__heading{
    padding-left: 15px;
}

//position arrows
.razzi--v-position-top{
    .razzi-images-carousel__group--arrows{
        position: absolute;
        right: 0;
        top: 0;
        display: flex;
        justify-content: space-between;
        align-items: center;
        padding-right: 15px;

        .rz-swiper-button {
            position: static;
            transform: none;
            width: auto;
            height: auto;
            line-height: normal;
        }
    }
}