.footer-links {
	--rz-footer-links-border-color: #2b2b2b;
    --rz-footer-links-top-spacing: 64px;
    --rz-footer-links-bottom-spacing: 64px;

	.site-footer-dark &,
    .site-footer-custom & {
		padding-top: var(--rz-footer-links-top-spacing);
		padding-bottom: var(--rz-footer-links-bottom-spacing);
    }

    .site-footer-light &,
    .site-footer-gray &{
        .footer-container {
			padding-top: var(--rz-footer-links-top-spacing);
			padding-bottom: var(--rz-footer-links-bottom-spacing);
        }
    }

	.widget {
		margin-bottom: 10px;
		border: none;
		padding: 0;

		.widget-title {
			border: none;
			text-transform: inherit;
		}

		&:last-child {
			margin-bottom: 0;
		}
	}

	.widget_nav_menu {
		.widget-title {
			font-size: 14px;
			font-weight: 500;
			display: inline-block;
			margin-bottom: 0;
			padding: 0 5px 0 0;

			& + * {
				display: inline-block;
			}

		}

		ul {
			display: flex;
			flex-wrap: wrap;
			li {
				display: inline-block;
				position: relative;
				padding: 0 10px;

				&:after {
					position: absolute;
					top: 0;
					right: 0;
					height: 12px;
					width: 1px;
					content: "|";
				}

				a {
					position: relative;
					font-size: 14px;
					color: var(--rz-text-color-gray);

					&:before {
						position: absolute;
						bottom: 0;
						right: 0;
						width: 0;
						height: 1px;
						content: "";
						transition: 0.35s;
					}

					&:hover {
						color: var(--rz-color-primary);

						&:before {
							width: 100%;
							left: 0;
							right: auto;
						}

						&::after {
							background-color: var(--rz-color-primary);
						}
					}
				}

				&:last-child {
					&:after {
						display: none;
					}
				}
			}
		}
	}

	&.has-divider{
        .footer-container {
            &:before {
                content: '';
                position: absolute;
                top: 0;
                left: 0;
                right: 0;
                width: 100%;
                height: 1px;
                background-color: var( --rz-footer-links-border-color );
            }
        }
    }
}