<?php
/**
 * Template file for displaying Home mobile
 *
 * @package Razzi
 */
?>

<a href="<?php echo esc_url( home_url( '/' ) ) ?>" class="rz-navigation-bar_icon home-icon">
	<?php echo \Razzi\Icon::get_svg( 'home', '', 'mobile' ); ?>
</a>
