ul.rz-cat-image li,
ul.rz-cat-page-header-bg li {
	display: inline-block;
	position: relative;
	margin-bottom: 0;
}

ul.rz-cat-image li.image,
ul.rz-cat-page-header-bg li.image {
	max-height: 100px;
	overflow: hidden;
}

ul.rz-cat-image li.image .actions,
ul.rz-cat-page-header-bg li.image .actions {
	position: absolute;
	top: 50%;
	left: 0;
	right: 0;
	transform: translateY(-50%);
	text-align: center;
	z-index: 20;
	transition: 0.5s;
	opacity: 0;
}

ul.rz-cat-image li.image:before,
ul.rz-cat-page-header-bg li.image:before {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background-color: rgba(0, 0, 0, 0.5);
	content: "";
	z-index: 10;
	transition: 0.5s;
	opacity: 0;
}

ul.rz-cat-image li.image:hover:before,
ul.rz-cat-image li.image:hover .actions,
ul.rz-cat-page-header-bg li.image:hover:before,
ul.rz-cat-page-header-bg li.image:hover .actions {
	opacity: 1;
}

ul.rz-cat-image li.image .actions .delete,
ul.rz-cat-page-header-bg li.image .actions .delete {
	color: #fff;
}

.rz-custom-elements p label {
	display: inline-block;
}

table.wp-list-table td.column-description {
	max-height: 75px;
	overflow-y: hidden;
	display: block;
}