.newsletter-popup-modal{
    h1, h2, h3, h4, h5, h6{
        color: var(--rz-color-dark);
        line-height: 1.357em;
    }

    .newsletter-title{
        color: var(--rz-color-dark);
        line-height: 1.357em;
        font-size: 28px;
        font-weight: 500;
        margin-bottom: 17px;
    }

    .button-close{
        top: 28px;
        right: 28px;
        transform: none;
        z-index: 10;
        color: #a0a0a0;
        cursor: pointer;

        &:hover {
            color: #a0a0a0;
        }
    }

    .modal-content{
        width: 830px;
        max-width: 90%;
        max-height: 600px;
        position: absolute;
        top: 50%;
        left: 50%;
        transform: translate(-50%, -50%);
        background-color: #fff;
        padding: 0;
    }

    .newsletter-popup-content{
        font-size: 18px;
        color: var(--rz-color-dark);
    }

    .n-close{
        font-size: 14px;
        color: #767676;
        position: relative;
        display: inline-flex;

        &:before{
            content: "";
            height: 18px;
            width: 18px;
            background-color: #e2e2e2;
            margin: 2px 14px 0 0;
            float: left;
            transition: 0.15s all ease-out;
            flex: none;
        }

        &:after{
            transform: rotate(45deg);
            content: "";
            width: 6px;
            height: 10px;
            display: block;
            border: solid #111111;
            border-width: 0 2px 2px 0;
            position: absolute;
            top: 5px;
            left: 6px;
            opacity: 0;
        }

        &.active{
            &:after{
                opacity: 1;
            }
        }
    }
}

.newsletter-popup-layout-1-column{
    .modal-content{
        padding: 10px;
        width: 570px;
    }

    .newsletter-popup-image{
        position: relative;
        min-height: 250px;
        display: flex;
        flex-direction: column;
        justify-content: center;
        align-items: center;
        text-align: center;

        &:before{
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(17, 17, 17, 0.3);
            z-index: 1;
        }
    }

    .newsletter-popup-image__holder{
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-size: cover;
    }

    .newsletter-popup-content{
        --rz-color-dark:#fff;
        position: relative;
        padding: 30px 0;
        z-index: 2;
        width: 63%;
    }

    .newsletter-popup-wrapper{
        padding: 50px 40px 20px;
        text-align: center;

        .newsletter-popup-content{
            display: none;
        }
    }

    .newsletter-popup-form{
        margin-bottom: 50px;

        .mc4wp-form-fields {
            display: flex;
            flex-wrap: wrap;

            input[type=email]{
                flex: 1;
                margin-right: 6px;
                height: 46px;
                padding: 0 23px;
            }

            input[type="submit"]{
                flex: 0;
                line-height: 46px;
                padding: 0 25px;
            }
        }

        .razzi-svg-icon{
            display: none;
        }
    }

    .button-close {
        color: #fff;

        &:hover {
            .razzi-svg-icon {
                color: #fff;
            }
        }
    }
}

.newsletter-popup-layout-2-columns{
    .modal-content{
        display: flex;
    }

    .newsletter-popup-image{
        flex: 0.92;
        line-height: 0;

        &.no-image{
            flex: none;
        }
    }


    .newsletter-popup-wrapper{
        flex: 1;
        padding: 110px 70px 26px;
    }

    .newsletter-popup-content{
        padding-bottom: 33px;
    }

    .newsletter-popup-form{
        position: relative;
        margin-bottom: 63px;
    }

    .mc4wp-form{
        position: relative;
        z-index: 1;
    }

    .mc4wp-form-fields {
        display: flex;
        flex-wrap: wrap;

        input[type=email]{
            flex: 1;
            margin-right: 6px;
            height: 46px;
            padding: 0 23px;
        }

        input[type="submit"]{
            line-height: 46px;
            height: 46px;
        }
    }
}