@media (max-width: 1199px) {
    .razzi-product-shortcode{
        &.single-product {
            div.product {
                .entry-summary {
                    padding-right: 0;
                }
            }
        }
    }

    .razzi-products-carousel__slidesperviewauto-yes .razzi-products-carousel {
        margin-right: 0 !important;

        ul.products li.swiper-item-empty {
            display: none;
        }
    }

    .razzi-products-carousel__centeredslides-yes{
        .swiper-slide{
            max-width: 100%;
        }
    }

    .razzi-images-carousel__slidesperviewauto-yes .razzi-images-carousel {
        .swiper-item-empty {
            display: none;
        }

        .swiper-slide{
            max-width: 100%;
            flex: none;
        }
    }
}