.navigation-bar-standard{
	--rz-navigation-bar-height: 50px;
	padding-bottom: var(--rz-navigation-bar-height);
}

.navigation-bar-simple,
.navigation-bar-standard {
	+ #gotop {
		bottom: 75px;
	}
}


.rz-navigation-bar_icon {
	font-size: 18px;
	line-height: 1;

	.icon-shop-cart {
		font-size: 20px;
	}

	&.cart-icon ,
	&.wishlist-icon {
		position: relative;

		.counter {
			position: absolute;
			top: -10px;
			right: 10px;
			font-size: 10px;
			font-weight: 500;
			color: var( --rz-background-text-color-primary );
			text-align: center;
			line-height: 11px;
			min-width: 18px;
			height: 18px;
			border-radius: 30px;
			padding: 4px;
			background-color: var( --rz-background-color-primary );
			display: inline-block;
		}
	}
}

.rz-navigation-bar {
	.add_to_cart_button {
		line-height: 1;

		&.loading {
			&:before {
				opacity: 1;
				width: 16px;
				height: 16px;
				display: inline-block;
				border-radius: 50%;
				border: 2px solid;
				border-color: transparent var( --rz-border-color-lighter ) var( --rz-border-color-lighter ) var( --rz-border-color-lighter );
				-webkit-animation: razzi-spin infinite 1s linear;
				animation: razzi-spin infinite 1s linear;
				transition: opacity .2s linear .2s;
				content: "";
			}

			.razzi-svg-icon {
				display: none;
			}
		}

		.add-to-cart-text {
			display: none;
		}
	}

	.checkout-text-button {
		display: none;
	}

	.added_to_cart {
		display: none;
	}

	.rz-loop_atc_button {
		.razzi-svg-icon{
			color: var(--rz-background-text-color-primary);
		}
	}

	&.hide {
		display: none;
	}
}

.rz-navigation-bar__standard {
	position: fixed;
	bottom: 0;
	left: 0;
	right: 0;
	z-index: 1100;
	background-color: #fff;
	border-top: 1px solid var(--rz-border-color-light);
	display: flex;
	align-items: center;
	justify-content: space-between;
	padding: 15px 15px 13px;
}

.rz-navigation-bar__simple {
	.add_to_cart_button,
	.rz-navigation-bar_icon {
		position: fixed;
		bottom: 15px;
		right: 15px;
		z-index: 1000;
		width: 40px;
		height: 40px;
		background-color: var(--rz-background-color-primary);
		border-radius: 100%;
		box-shadow: 0px 0px 3px rgba( 255, 255, 255, 0.3);
		font-size: 15px;
		display: flex;
		justify-content: center;
		align-items: center;

		&.filter-icon {
			margin-top: 5px;
		}

		.razzi-svg-icon{
			color: var(--rz-background-text-color-primary);
		}

		.icon-shop-cart {
			font-size: 18px;
			margin-top: -2px;
		}
	}

}

.rz-navigation-bar.rz-navigation-bar--floating-button {
	padding: 0;
	.rz-loop_atc_button {
		background-color: var(--rz-background-color-dark);
		color: var(--rz-color-lighter);
		width: 100%;
		right: 0;
		left: 0;
		bottom: 0;
		border-radius: 0;
		font-size: 16px;
		height: 54px;
		line-height: 54px;
		text-align: center;

		.add-to-cart-text,
		.checkout-text-button {
			display: inline-block;
			padding-left: 10px;
		}

		&:not(.loading).razzi-svg-icon {
			display: inline-block;
		}

	}
}

.rz-navigation-bar_items-left {
	.rz-navigation-bar_icon {
		right: auto;
		left: 15px;
	}
}

.rz-navigation-bar_items-center {
	.rz-navigation-bar_icon {
		right: 50%;
		transform: translateX(50%);
	}
}

.rz-navigation-bar__sticky-atc {
	.price {
		font-size: 24px;
		font-weight: 500;
		color: var(--rz-color-dark);
		margin: 0;

		del {
			margin-right: 13px;
			font-size: 18px;
			color: #a0a0a0;
		}

		ins {
			background-color: transparent;
			color: var(--rz-color-primary);
		}
	}

	.add_to_cart_button,
	.rz-loop_atc_button {
		order: 2;
		font-size: 15px;
		text-align: center;
		width: 40px;
		height: 40px;
		line-height: 45px;
		border-radius: 100%;
		background-color: var(--rz-background-color-primary);
		box-shadow: 0px 0px 3px #fff;
		position: relative;
		outline: none;
	}

	.checkout_button {
		font-size: 18px;
	}
}

.rz-navigation-bar__type-variable {
	position: fixed;
    right: 0;
	bottom: 0;
	width: 100%;
	z-index: 1000;
}

.rz-navigation-bar__type-variable--header {
	display: flex;
	justify-content: space-between;
	width: 100%;
}

.rz-navigation-bar__type-variable--content {
	display: none;
	width: 100%;
	position: absolute !important;
	left: 0;
	right: 0;
	bottom: 0;
	padding: 30px 15px;
	background-color: var( --rz-background-color-light );
	z-index: 9999;

	.product-size-guide {
		display: none;
	}

	form.cart {
		.variations {
			border: none;

			tr {
				display: flex;
				flex-direction: column;
				justify-content: center;
				align-items: center;

				&:not(:last-child) {
					margin-bottom: 20px;
				}
			}

			td {
				border: none;
				padding: 0;
			}

			td.label {
				margin-bottom: 10px;
				font-weight: 500;
			}
		}

		.rz-wishlist-button ,
		.rz-buy-now-button {
			display: none;
		}

		.product-button-wrapper button.single_add_to_cart_button {
			min-width: 200px;
		}
	}
}

.rz-navigation-bar__btn-close {
	position: absolute;
	right: 25px;
}

.rz-navigation-bar__type-out-of-stock {
	justify-content: center;
}

.rz-navigation-bar__btn-place-order {
	width: 100%;
}

.rz-navigation-bar__add-to-order {
	padding: 0;
}

.rz-navigation-bar__off-layer {
	position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    cursor: pointer;
    background-color: var(--rz-background-color-dark);
	opacity: 0;
	z-index: -1;
	transition: .3s;

	&.active {
		opacity: .5;
		z-index: 9;
	}
}

.single-product {
	div.product {
		&.rz-navigation-bar__type-variable--content{
			.product-button-wrapper {
				flex-wrap: nowrap;

				> * {
					margin-bottom: 0;
				}

				.single_add_to_cart_button {
					margin: 0 0 0 15px;
				}

				.quantity .qty-dropdown .qty-options {
					top: auto;
					bottom: calc(100% - 1px);
				}
			}
		}
	}
}

.single-product,
.woocommerce-cart {
	.navigation-bar-standard {
		--rz-navigation-bar-height: 70px;
	}
}