.single-product {
	div.product {
		position: relative;

		.entry-summary {
			width: 51.3%;
			padding-left: 100px;
			float: right;

			.meta-cat:not(:hover) {
				color: var(--rz-text-color-gray);
			}

			.meta-cat > img{
				max-height: 60px;
				width: auto;
				display: block;
			}

			.star-rating {
				font-size: 18px;
				margin-top: 2px;
			}

			.product_title {
				font-size: 28px;
			}

			.woocommerce-product-rating {
				display: flex;
				align-items: center;
			}

			.price {
				font-size: 24px;
				font-weight: 500;
				color: var(--rz-color-dark);
				margin: 0;

				del {
					margin-right: 13px;
					font-size: 18px;
					color: #a0a0a0;
				}

				ins {
					background-color: transparent;
					color: var(--rz-color-primary);
				}
			}

			.woocommerce-review-link {
				margin-left: 10px;
			}

			.yith-wcwl-add-to-wishlist {
				margin: 0;
				line-height: 52px;
			}
		}

		.summary-top-box {
			display: flex;
			justify-content: space-between;
			margin-bottom: 5px;
			align-items: center;
		}

		.summary-price-box {
			display: flex;
			align-items: center;
			margin: 0 0 20px;

			.price {
				margin-right: 16px;
			}

			.rz-stock {
				color: var(--rz-color-dark);
			}
		}

		.single-product-extra-content {
			margin-top: 30px;
			.widget {
				border: none;
				padding: 0;
				margin-bottom: 30px;

				strong {
					color: #111;
				}

				ul {
					margin: 10px 0 0;
					&.razzi-list-check {
						li {
							position: relative;
							list-style: none;

							&:before {
								position: absolute;
								top: 4px;
								left: -22px;
								content: "";
								display: block;
								width: 14px;
								height: 14px;
								background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlwSFlzAAAAWQAAAFkBqp2phgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoAAAD7SURBVDiNrdMvToNBEAXw3xAUh6isAwOyeLC4ktRUoMsJ4AINHoFEIDBNOUFDUsEFCLo4HFUkg2A/sjT9CEmZZMT8ee/N7s5GZqotIro4xX5xeCp+m5nPPwCZqZAERlhijjH6xccltyw98Y2rwFO8YdAUVx2D0jNtSJrCqBQ6beCKpFN6R83xu2W0VuWWSZYF6xLzP4BOcFTFc1xslZue+cUiYog77FTpGQ5ggX7FvIfdKh7iA8OVifpYbK0RPMRjRPSK8jXOMvOmbcIJxivsV3hfp1z1jDHZ9rVhxzVjZp5HxAteM/O+RbiHBzZ9xo0X6V9WeZPPFJt+50/sUV+QbazEbgAAAABJRU5ErkJggg==");
								background-size: cover;
							}
						}
					}

				}

				fieldset {
					margin-top: 0.5em;
					margin-bottom: 1.2em;
					border: 1px solid #e2e2e2;

					legend {
						display: block;
						margin: 0 auto;
						width: inherit;
						padding: 10px;
						color: #111;
						font-size: 14px;
						font-weight: 600;
						text-align: center;
					}
				}
			}
		}
	}
}

form.cart {
	.wcpa_form_outer {
		width: 100%;

		.wcpa_form_item {
			&  > label {
				color: var(--rz-color-dark);
				margin-bottom: 5px;
			}

		 	input[type="text"],
			input[type="date"],
			input[type="number"],
			input[type="email"],
			input[type="tel"],
			input[type="datetime-local"],
			input[type="file"],
			textarea {
				border: 1px solid var(--rz-border-color);
				padding: 12px 15px;
				width: 100%;
			}

			.wcpa_radio input[type="radio"]:checked + label .wcpa_check {
				border-color: var(--rz-color-dark);
				&::before {
					background-color: var(--rz-color-dark);
				}
			}

			.wcpa_checkbox input[type="checkbox"]:checked + label .wcpa_check {
				border-color: var(--rz-color-dark);
				background-color: transparent;

				&::before {
					border-color: var(--rz-color-dark);
				}
			}

		}



	}
}

// Degree Product
.pswp {
	.razzi-video-wrapper iframe,
	.razzi-video-wrapper .wp-video {
		position: absolute;
		top: 50%;
		left: 50%;
		transform: translate(-50%, -50%);

	}

	.razzi-video-wrapper iframe:-webkit-full-screen {
		transform: none;
	}
}