.razzi-faq{
    .faq-title{
        font-size: 18px;
        margin: 0;
        display: flex;
        justify-content: space-between;
    }

    .faq-desc{
        margin-top: 23px;
        margin-bottom: 4px;

        p {
            margin: 0;
        }
    }

    .box-content{
        padding: 21px 0;
        border-style: solid;
        border-color: #e2e2e2;
        border-width: 1px 0 0;
        cursor: pointer;

        .razzi-svg-icon{
            color: #1f1f1f;
            padding-top: 6px;
            padding-left: 25px;

            svg {
                transform: rotate(0);
                transition: ease .3s;
            }
        }

        .icon-active {
            display: none;
        }

        &.active{
            .razzi-svg-default svg{
                transform: rotate(180deg);
            }

            .icon-normal {
                display: none;
            }

            .icon-active {
                display: inline-block;
            }
        }

        &:last-child{
            border-bottom-width: 1px;
        }
    }
}